% -------------------------------------------------------------------------
% Koijen, Philipson, and Uhlig (2014): "Financial Health Economics"
% 
% The code generates Table 5
% 
% -------------------------------------------------------------------------

clear all; close all; clc

%% Settings
idaysbeta   = 250;
iwindow     = 10;

%% Compute betas by permno
vpermno_m   = xlsread('..\..\Data\event_studies_m_2014.xlsx','Sheet1','A1:A30386');
vr_e_i_m    = xlsread('..\..\Data\event_studies_m_2014.xlsx','Sheet1','I1:I30386');
mrff_m      = xlsread('..\..\Data\event_studies_m_2014.xlsx','Sheet1','D1:F30386');
vhc_m       = xlsread('..\..\Data\event_studies_m_2014.xlsx','Sheet1','H1:H30386');
vrf         = xlsread('..\..\Data\event_studies_m_2014.xlsx','Sheet1','G1:G30386');
vhc_e_m     = vhc_m - vrf;

vpermno_m_u = unique(vpermno_m);
dN          = length(vpermno_m_u);
for i = 1 : dN,
    vind                = find(vpermno_m==vpermno_m_u(i));
    vbeta               = regress(vr_e_i_m(vind),[ones(length(vind),1) mrff_m(vind,1) vhc_e_m(vind)]);
    vHC_b(i,1)          = vbeta(end);
    vno_obs_m(i,1)      = length(vind);
end

%% Compute CARs
ve_y        = [1992;1992;1992;1992;1992;1992;1992;1993;1993;1993;1993];
ve_m        = [1;2;3;4;6;9;11;1;2;9;9];
ve_d        = [19;18;10;7;4;24;3;25;12;11;22];
dno_events  = length(ve_y);

% Load data
vpermno_d       = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','A1:A91200');
vy              = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','B1:B91200');
vm              = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','C1:C91200');
vd              = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','D1:D91200');
vr_e_i_d        = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','E1:E91200');
mrff_d          = xlsread('..\..\Data\daily_merged_event_studies_2014.xlsx','Sheet1','F1:H91200');
vpermno_d_u     = unique(vpermno_d);

% Compute CAR for each stock
for i = 1 : length(vpermno_d_u),
    vind        = find(vpermno_d == vpermno_d_u(i));
    vy_s        = vy(vind);
    vm_s        = vm(vind);
    vd_s        = vd(vind);
    vr_s        = vr_e_i_d(vind);
    mrb_s       = mrff_d(vind,:);
    
    dCAR    = 0;
    for j = 1 : dno_events,
        dind    = find(vy_s == ve_y(j) & vm_s == ve_m(j) & vd_s == ve_d(j));
        if length(dind)==1,
            % Estimate beta
            vbeta   = regress(vr_s(dind-idaysbeta-iwindow/2:dind-iwindow/2-1),[ones(idaysbeta,1) mrb_s(dind-idaysbeta-iwindow/2:dind-iwindow/2-1,1)]);
            
            % Compute CAR
            vCAR_i  = vr_s(dind - iwindow/2 : dind + iwindow/2) - [ones(iwindow+1,1) mrb_s(dind - iwindow/2 : dind + iwindow/2,1)] * vbeta;
            dCAR    = sum(vCAR_i) + dCAR;
        end
    end
    vCAR(i,1)   = dCAR;
end

disp('Average cumulative abnormal return')
disp([nanmean(vCAR)])

%% Link health-care beta to the CAR
vind    = find(isnan(vCAR)==0);             % Caused by missing daily return observations.
vres    = nwest(vCAR(vind),[ones(length(vind),1) vHC_b(vind)/std(vHC_b(vind))],0);
disp([vres.beta vres.tstat [vres.rsqr;0]])

disp('Number of firms')
disp(length(vind))

disp('Average number of observation used to estimate the health care beta')
disp(mean(vno_obs_m))



















