function dummy = dispmat(B,varargin);
% dispmat(B) takes a complex-valued matrix B and prints it with a fixed format,
% leaving out imaginary parts and using 0 for real parts, if they are
% small.
% dispmat(B,FLT,BLK,TEX,FREE) or shortened versions thereof produce output with some
% control parameters, together with their defaults:
% 2 = FLT: number of floating point numbers
% 1 = BLK: number of blanks between numbers
% 0 = TEX: =1, if you want array output for a LaTEX file, else 0
% 1 = FREE: = 1, if size of integers dictates formats.  = 0 to force a length.
% Thus, e.g.
% dispmat(B,3,2,1) sets FREE = 1 per default, and produces a LaTEX array
% with three floating point numbers and 2 blanks between numbers.
% dispmat(B,0,0) for a positive matrix produces integer output with one
% blank in between and if B has some negative entries, the blank is replaced with a minus sign.
% The function returns the dummy value 0: ignore it.
% copyright: H. Uhlig, huhlig@uchicago.edu, Jan 2008

optargin=size(varargin,2);

if nargin == 0,
    disp('dispmat(B) takes a complex-valued matrix B and prints it with a fixed format,');
    disp('leaving out imaginary parts and using 0 for real parts, if they are');
    disp('small. ');
    disp('dispmat(B,FLT,BLK,TEX,FREE) or shortened versions thereof produce output with some');
    disp(' control parameters, together with their defaults:');
    disp(' 2 = FLT: number of floating point numbers');
    disp(' 1 = BLK: number of blanks between numbers');
    disp(' 0 = TEX: =1, if you want array output for a LaTEX file, else 0');
    disp(' 1 = FREE: = 1, if size of integers dictates formats.  = 0 to force a length.');
    disp(' Thus, e.g.');
    disp(' dispmat(B,3,2,1) sets FREE = 1 per default, and produces a LaTEX array');
    disp(' with three floating point numbers and 2 blanks between numbers. ');
    disp(' dispmat(B,0,0) for a positive matrix produces integer output with one blank in between');
    disp(' and if B has some negative entries, the blank is replaced with a minus sign.');
    disp(' The function returns the dummy value 0: ignore it.');
    disp(' copyright: H. Uhlig, huhlig@uchicago.edu, Jan 2008');
else
    if optargin > 0,
        FLT = varargin{1};
    else
        FLT = 2; % number of floating point numbers
    end;

    if optargin > 1,
        BLK = varargin{2};
    else
        BLK = 1;  % number of blanks between numbers
    end;

    if optargin > 2,
        TEX = varargin{3};
    else
        TEX = 0; % = 0: no LaTEX output, = 1: LaTEX output
    end;

    if optargin > 3,
        FREE = varargin{4};
    else
        FREE = 1; % = 0: forces a default format.  = 1: adapts the format to options and length of integers
    end;

    [n1,n2]=size(B);

    blkstrg='';
    for j = 1 : BLK,
        blkstrg=[blkstrg,' '];
    end;

    eps=10^(-FLT-1);

    if n1 == 1,
        strgcrit =  abs(imag(B)) > eps;
        realdig =  floor(max(0,log10(abs(real(B))))) ;
        imagdig =  floor(max(0,log10(abs(imag(B)))));
    else
        strgcrit = max(abs(imag(B))) > eps;
        realdig = max(floor(max(0,log10(abs(real(B))))));
        imagdig = max(floor(max(0,log10(abs(imag(B))))));
    end;
    strg='      ';
    if TEX,
        strgtex='';
        for j = 1 : n2,
            strgtex=[strgtex,'c'];
        end;
        disp(['\begin{tabular}{',strgtex,'}']);
    end;
    for t = 1 : n1,
        s = [];
        for omj = 1 : n2,
            realstrg=['%',sprintf('%1.0f.%1.0ff',realdig(omj)+2+(FLT>0)+FLT,FLT)];
            realnull=['%',sprintf('%1.0f.%1.0ff',realdig(omj)+2+(FLT>0)+FLT,0)];
            imagstrg=['%',sprintf('%1.0f.%1.0ffi',imagdig(omj)+1+(FLT>0)+FLT,FLT)];
            imagblk = '';
            for j = 1 : imagdig(omj)+3+(FLT>0)+FLT
                imagblk=[imagblk,' '];
            end;
            if abs(imag(B(t,omj))) > eps,
                if imag(B(t,omj))>0,
                    if FREE,
                        s=[s,sprintf([realstrg,'+',imagstrg,blkstrg],real(B(t,omj)),imag(B(t,omj)))];
                    else
                        s=[s,sprintf('%5.2f+%4.2fi ',real(B(t,omj)),imag(B(t,omj)))];
                    end;
                else
                    if FREE,
                        s=[s,sprintf([realstrg,'-',imagstrg,blkstrg],real(B(t,omj)),-imag(B(t,omj)))];
                    else
                        s=[s,sprintf('%5.2f-%4.2fi ',real(B(t,omj)),-imag(B(t,omj)))];
                    end
                end;
            else
                if abs(real(B(t,omj))) < eps,
                    if FREE,
                        s=[s,sprintf(realnull,0)];
                    else
                        s=[s,' 0    '];
                    end
                else
                    if FREE,
                        s=[s,sprintf(realstrg,real(B(t,omj)))];
                    else
                        s=[s,sprintf('%5.2f ',real(B(t,omj)))];
                    end;
                end;
                if strgcrit(omj),
                    if FREE,
                        s=[s,imagblk,blkstrg];
                    else
                        s=[s,strg];
                    end
                else
                    if FREE,
                        s=[s,blkstrg];
                    else
                        s=[s,''];
                    end
                end;
            end;
            if TEX,
                if omj < n2,
                    s = [s,'&'];
                else
                    s = [s,'\\'];
                end;
            end;
        end;
        disp(s);
    end;
    if TEX,
        disp('\end{tabular}');
    end;
end;
dummy=0;