function    df     = solve_RDlogD_2014_10_09(log_dd_in)   
% function    df     = solve_RD(log_dd_in)
% Note: this is a function of log(d), not d: change in 2014-10-09
% dd_in is a "guess" at the correct solution for the R&D effort d.  If the guess is correct, df = 0.
% This is a check that the equation (23) in 2014_09_29_HU is satisfied

% Labor Share ...dtheta_labshare ...  added 2014-09-29
global      dsigma dxi dh_bar dphi domega dM_low dy_t dgamma da_t dnu dchi dtheta_labshare

dd_in = exp(log_dd_in);   % added 2014-10-09

% Given the exponentiation, the next check is now irrelevant ... 
% but never mind, it cannot hurt either:
penalty = max(-dd_in,0);  % added 2014-04-16
dd_in = max(dd_in,1e-20); % added 2014-04-16

% Examine equation (23) in 2014_09_29_HU.
% First, figure out E[ M(t+1) pi(t+1)].  We need to calculate three terms
dt1         = (1 - domega) * dM_low * dy_t * dgamma; 
      % = E_t[ M(t+1) y(t+1) ] = (1-omega) M_low * y(t) * gamma
dt2         = dtheta_labshare * (1 - dxi) / (1 - dxi*dsigma) / dphi; 
      % the first term of (19) in 2014_09_29_HU, divided by Phi
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %
      % Compared to earlier versions, there now is the dtheta_labshare
      % 
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
da_next_inv     = (da_t^dnu + (dd_in)^dnu)^(-1/dnu);
      % = q(t+1)^(-1)=(q(t)^nu+d(t)^nu)^(-1/nu), see equation (9) in 2014_09_29_HU
dt3         = (1 - dsigma) / (1 - dxi*dsigma) * dxi * dh_bar * da_next_inv;  
      % the second term of (19) in 2014_09_29_HU, divided by Phi, where
      % we note, that p(t+1) = Phi/q(t+1), see equation (14) in 2014_09_29_HU
% Thus, (dt2 - dt3)*Phi is the share phi(t+1) of labor output that will be spent on health care, 
% see equation (19) in 2014_09_29_HU.
% Profits are a fraction (Phi - 1)/Phi of this, see equation (16) in 2014_09_29_HU.  
% Hence, profits in (t+1) are
% (Phi - 1)*(dt2 - dt3)*y(t)*gamma, since y(t+1) = y(t)*gamma.  With this
% E[ M(t+1) pi(t+1)] = (Phi - 1) * (dt2 - dt3) *  dt1

DO_NEW_CRITERION = 1;
if DO_NEW_CRITERION,
    da_next_pow_nu     = da_t^dnu + (dd_in)^dnu;
    % = q(t+1)^nu=q(t)^nu+d(t)^nu, see equation (9) in 2014_09_29_HU
    
    % df          =  1e3*((dd_in)^dnu * dt1 * (dt2 - dt3) - (1-dchi) * dd_in * da_next_pow_nu);
    % this is equation (23) in 2014_09_29_HU, multiplied with d and q(t+1)^nu and the lhs subtracted.
    % Note that (Phi - 1) in the numerator of the rhs of (19) has been cancelled with (Phi - 1) in the expression for E[ M(t+1) pi(t+1)]
   
    % df          =  1e3*(((dd_in)^dnu/da_next_pow_nu) * dt1 * (dt2 - dt3) - (1-dchi) * dd_in);
    df          =  1e3*(((dd_in)^(dnu-1)/da_next_pow_nu) * dt1 * (dt2 - dt3) - (1-dchi));

    % penalizing negative dd_in:   
    df = (1 + 100*penalty)*df;
else % this was the previous code, before 2014-09-29.  For nu slightly negative, this led to failures of fsolve   
    da_next     = (da_t^dnu + (dd_in)^dnu)^(1/dnu);
    % = q(t+1)=(q(t)^nu+d(t)^nu)^(1/nu), see equation (9) in 2014_09_29_HU
    df          =  1e3*((dd_in)^dnu /(da_next^dnu) * dt1 * (dt2 - dt3) - (1-dchi) * dd_in);
    % this is equation (23) in 2014_09_29_HU, multiplied with d and the lhs subtracted.
    % Note that (Phi - 1) in the numerator of the rhs of (19) has been cancelled with (Phi - 1) in the expression for E[ M(t+1) pi(t+1)]
    
    % penalizing negative dd_in:   
    df = (1 + 100*penalty)*df;
end;

% A piece of brute-force code to keep this running, added 2014-10-1, HU
df = real(df);
df = min(max( df, - 1e20),1e20);



